<p class="text-muted">
    * A value estimate represents an estimated monthly income calculated with reprocessed ores,
    current average market prices,
    a reprocessing yield of {{ reprocessing_yield|floatformat }}%
    and an assumed monthly ore volume of {{ total_volume_per_month|floatformat:"1" }} million m3. All values in B ISK.
</p>
