/* Owned value */
#table_owned_value thead th:nth-child(4) {
	text-align: right;
}
#table_owned_value thead th:nth-child(5) {
	text-align: right;
}
#table_owned_value thead th:nth-child(6) {
	text-align: right;
}
#table_owned_value thead th:nth-child(7) {
	text-align: right;
}
#table_owned_value tbody td:nth-child(4) {
	text-align: right;
}
#table_owned_value tbody td:nth-child(5) {
	text-align: right;
}
#table_owned_value tbody td:nth-child(6) {
	text-align: right;
}
#table_owned_value tbody td:nth-child(7) {
	text-align: right;
}
#table_owned_value tfoot th:nth-child(4) {
	text-align: right;
}
#table_owned_value tfoot th:nth-child(5) {
	text-align: right;
}
#table_owned_value tfoot th:nth-child(6) {
	text-align: right;
}
#table_owned_value tfoot th:nth-child(7) {
	text-align: right;
}
.report-title {
	font-size: x-large;
}
/* user mining */
#table_user_mining thead th:nth-child(4) {
	text-align: right;
}
#table_user_mining thead th:nth-child(5) {
	text-align: right;
}
#table_user_mining thead th:nth-child(6) {
	text-align: right;
}
#table_user_mining thead th:nth-child(7) {
	text-align: right;
}
#table_user_mining thead th:nth-child(8) {
	text-align: right;
}
#table_user_mining thead th:nth-child(9) {
	text-align: right;
}
#table_user_mining thead th:nth-child(10) {
	text-align: right;
}
#table_user_mining thead th:nth-child(11) {
	text-align: right;
}
#table_user_mining tbody td:nth-child(4) {
	text-align: right;
}
#table_user_mining tbody td:nth-child(5) {
	text-align: right;
}
#table_user_mining tbody td:nth-child(6) {
	text-align: right;
}
#table_user_mining tbody td:nth-child(7) {
	text-align: right;
}
#table_user_mining tbody td:nth-child(8) {
	text-align: right;
}
#table_user_mining tbody td:nth-child(9) {
	text-align: right;
}
#table_user_mining tbody td:nth-child(10) {
	text-align: right;
}
#table_user_mining tbody td:nth-child(11) {
	text-align: right;
}
#table_user_mining tfoot th:nth-child(4) {
	text-align: right;
}
#table_user_mining tfoot th:nth-child(5) {
	text-align: right;
}
#table_user_mining tfoot th:nth-child(6) {
	text-align: right;
}
#table_user_mining tfoot th:nth-child(7) {
	text-align: right;
}
#table_user_mining tfoot th:nth-child(8) {
	text-align: right;
}
#table_user_mining tfoot th:nth-child(9) {
	text-align: right;
}
#table_user_mining tfoot th:nth-child(10) {
	text-align: right;
}
#table_user_mining tfoot th:nth-child(11) {
	text-align: right;
}
